/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#define PATTERN_SUBNET	1
#define PATTERN_RANGE	2
#define PATTERN_IP		3

typedef int uint32_t;

struct Pattern_Subnet {
	uint32_t IP;
	uint32_t Last;
	int Valid;
};

struct Pattern_Range {
	uint32_t IP;
	uint32_t Start_IP;
	uint32_t End_IP;
	int Valid;
};

struct Pattern_Address {
	uint32_t IP;
	int Valid;
};

struct Pattern {
	int Type;
	struct Pattern_Subnet *Pattern_Subnet;
	struct Pattern_Range *Pattern_Range;
	struct Pattern_Address *Pattern_Address;
	int Valid;
};

struct IP_Address {
	uint32_t IP;
	int Done;
};


int Have_Patterns();
void IP_To_String(uint32_t IP, char *Buffer, int Size);
void Display_IP(uint32_t IP);
void Display_IP_Address(struct IP_Address *IP);
void Get_Next_IP_Subnet(struct Pattern_Subnet *Pattern, struct IP_Address *Result);
void Get_Next_IP_Range(struct Pattern_Range *Pattern, struct IP_Address *Result);
void Get_Next_IP_Address(struct Pattern_Address *Pattern, struct IP_Address *Result);
void Get_Next_IP_Pattern(struct Pattern *Pattern, struct IP_Address *Result);
int Get_Next_IP(uint32_t *IP_Address);
struct Pattern_Subnet *Parse_Pattern_Subnet(char *Pattern);
struct Pattern_Range *Parse_Pattern_Range(char *Pattern);
struct Pattern_Address *Parse_Pattern_Address(char *Pattern);
struct Pattern *Parse_Pattern(char *Pattern, int Type);
int IP_Pattern_Valid(char *Pattern);
struct Pattern* CopyPattern(struct Pattern *Old);
void Free_IP_Pattern(struct Pattern *Pattern);
void Free_All_Patterns();
const char* Pattern_Type_To_String(int Type);
int New_IP_Pattern(char *Pattern);
